# screen_capture

This is a "Windows only" redued fork of the XCap the cross-platform screen capture library originally written by nashaofu. It adds some custom logic to caputre given window handles, which are not available in XCap.


## License

This project is licensed under the Apache License. See the [LICENSE](./LICENSE) file for details.
